summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorBram Moolenaar <Bram@vim.org>2006-08-29 15:30:07 +0000
committerBram Moolenaar <Bram@vim.org>2006-08-29 15:30:07 +0000
commit89d4032cae3f1e525978bea5015434af677faa44 (patch)
tree1dd68f886ab03aed49d4e5647ee6f5296742c9e0
parent4100af7840a735cced72f1d20121850cea150a0d (diff)
updated for version 7.0-070v7.0.070
-rw-r--r--src/edit.c14
-rw-r--r--src/eval.c36
-rw-r--r--src/ex_cmds.c4
-rw-r--r--src/ex_cmds2.c8
-rw-r--r--src/ex_docmd.c63
-rw-r--r--src/gui_beval.c10
-rw-r--r--src/gui_gtk.c14
-rw-r--r--src/gui_gtk_x11.c24
-rw-r--r--src/hardcopy.c51
-rw-r--r--src/if_cscope.c6
-rw-r--r--src/main.c10
-rw-r--r--src/mbyte.c10
-rw-r--r--src/memline.c8
-rw-r--r--src/netbeans.c39
-rw-r--r--src/normal.c4
-rw-r--r--src/option.c21
-rw-r--r--src/os_unix.c14
-rw-r--r--src/quickfix.c2
-rw-r--r--src/regexp.c8
-rw-r--r--src/screen.c8
-rw-r--r--src/search.c19
-rw-r--r--src/spell.c128
-rw-r--r--src/ui.c3
-rw-r--r--src/undo.c16
-rw-r--r--src/version.c2
-rw-r--r--src/window.c2
26 files changed, 267 insertions, 257 deletions
diff --git a/src/edit.c b/src/edit.c
index a3d4a9af19..b5ab7a039f 100644
--- a/src/edit.c
+++ b/src/edit.c
@@ -129,7 +129,7 @@ static expand_T compl_xp;
static void ins_ctrl_x __ARGS((void));
static int has_compl_option __ARGS((int dict_opt));
-static int ins_compl_add __ARGS((char_u *str, int len, int icase, char_u *fname, char_u **cptext, int cdir, int flags, int dup));
+static int ins_compl_add __ARGS((char_u *str, int len, int icase, char_u *fname, char_u **cptext, int cdir, int flags, int adup));
static int ins_compl_equal __ARGS((compl_T *match, char_u *str, int len));
static void ins_compl_longest_match __ARGS((compl_T *match));
static void ins_compl_add_matches __ARGS((int num_matches, char_u **matches, int icase));
@@ -2118,7 +2118,7 @@ ins_compl_add_infercase(str, len, icase, fname, dir, flags)
* maybe because alloc() returns NULL, then FAIL is returned.
*/
static int
-ins_compl_add(str, len, icase, fname, cptext, cdir, flags, dup)
+ins_compl_add(str, len, icase, fname, cptext, cdir, flags, adup)
char_u *str;
int len;
int icase;
@@ -2126,7 +2126,7 @@ ins_compl_add(str, len, icase, fname, cptext, cdir, flags, dup)
char_u **cptext; /* extra text for popup menu or NULL */
int cdir;
int flags;
- int dup; /* accept duplicate match */
+ int adup; /* accept duplicate match */
{
compl_T *match;
int dir = (cdir == 0 ? compl_direction : cdir);
@@ -2140,7 +2140,7 @@ ins_compl_add(str, len, icase, fname, cptext, cdir, flags, dup)
/*
* If the same match is already present, don't add it.
*/
- if (compl_first_match != NULL && !dup)
+ if (compl_first_match != NULL && !adup)
{
match = compl_first_match;
do
@@ -3608,7 +3608,7 @@ ins_compl_add_tv(tv, dir)
{
char_u *word;
int icase = FALSE;
- int dup = FALSE;
+ int adup = FALSE;
char_u *(cptext[CPT_COUNT]);
if (tv->v_type == VAR_DICT && tv->vval.v_dict != NULL)
@@ -3625,7 +3625,7 @@ ins_compl_add_tv(tv, dir)
if (get_dict_string(tv->vval.v_dict, (char_u *)"icase", FALSE) != NULL)
icase = get_dict_number(tv->vval.v_dict, (char_u *)"icase");
if (get_dict_string(tv->vval.v_dict, (char_u *)"dup", FALSE) != NULL)
- dup = get_dict_number(tv->vval.v_dict, (char_u *)"dup");
+ adup = get_dict_number(tv->vval.v_dict, (char_u *)"dup");
}
else
{
@@ -3634,7 +3634,7 @@ ins_compl_add_tv(tv, dir)
}
if (word == NULL || *word == NUL)
return FAIL;
- return ins_compl_add(word, -1, icase, NULL, cptext, dir, 0, dup);
+ return ins_compl_add(word, -1, icase, NULL, cptext, dir, 0, adup);
}
#endif
diff --git a/src/eval.c b/src/eval.c
index 61654345eb..76a3ff4ff6 100644
--- a/src/eval.c
+++ b/src/eval.c
@@ -454,7 +454,7 @@ static int find_internal_func __ARGS((char_u *name));
static char_u *deref_func_name __ARGS((char_u *name, int *lenp));
static int get_func_tv __ARGS((char_u *name, int len, typval_T *rettv, char_u **arg, linenr_T firstline, linenr_T lastline, int *doesrange, int evaluate, dict_T *selfdict));
static int call_func __ARGS((char_u *name, int len, typval_T *rettv, int argcount, typval_T *argvars, linenr_T firstline, linenr_T lastline, int *doesrange, int evaluate, dict_T *selfdict));
-static void emsg_funcname __ARGS((char *msg, char_u *name));
+static void emsg_funcname __ARGS((char *ermsg, char_u *name));
static void f_add __ARGS((typval_T *argvars, typval_T *rettv));
static void f_append __ARGS((typval_T *argvars, typval_T *rettv));
@@ -2260,7 +2260,7 @@ ex_let_one(arg, tv, copy, endchars, op)
EMSG(_(e_letunexp));
else
{
- char_u *tofree = NULL;
+ char_u *ptofree = NULL;
char_u *s;
p = get_tv_string_chk(tv);
@@ -2269,7 +2269,7 @@ ex_let_one(arg, tv, copy, endchars, op)
s = get_reg_contents(*arg == '@' ? '"' : *arg, TRUE, TRUE);
if (s != NULL)
{
- p = tofree = concat_str(s, p);
+ p = ptofree = concat_str(s, p);
vim_free(s);
}
}
@@ -2278,7 +2278,7 @@ ex_let_one(arg, tv, copy, endchars, op)
write_reg_contents(*arg == '@' ? '"' : *arg, p, -1, FALSE);
arg_end = arg + 1;
}
- vim_free(tofree);
+ vim_free(ptofree);
}
}
@@ -7595,8 +7595,8 @@ call_func(name, len, rettv, argcount, argvars, firstline, lastline,
* Give an error message with a function name. Handle <SNR> things.
*/
static void
-emsg_funcname(msg, name)
- char *msg;
+emsg_funcname(ermsg, name)
+ char *ermsg;
char_u *name;
{
char_u *p;
@@ -7605,7 +7605,7 @@ emsg_funcname(msg, name)
p = concat_str((char_u *)"<SNR>", name + 3);
else
p = name;
- EMSG2(_(msg), p);
+ EMSG2(_(ermsg), p);
if (p != name)
vim_free(p);
}
@@ -9179,25 +9179,25 @@ filter_map(argvars, rettv, map)
typval_T save_key;
int rem;
int todo;
- char_u *msg = map ? (char_u *)"map()" : (char_u *)"filter()";
+ char_u *ermsg = map ? (char_u *)"map()" : (char_u *)"filter()";
int save_did_emsg;
rettv->vval.v_number = 0;
if (argvars[0].v_type == VAR_LIST)
{
if ((l = argvars[0].vval.v_list) == NULL
- || (map && tv_check_lock(l->lv_lock, msg)))
+ || (map && tv_check_lock(l->lv_lock, ermsg)))
return;
}
else if (argvars[0].v_type == VAR_DICT)
{
if ((d = argvars[0].vval.v_dict) == NULL
- || (map && tv_check_lock(d->dv_lock, msg)))
+ || (map && tv_check_lock(d->dv_lock, ermsg)))
return;
}
else
{
- EMSG2(_(e_listdictarg), msg);
+ EMSG2(_(e_listdictarg), ermsg);
return;
}
@@ -9229,7 +9229,7 @@ filter_map(argvars, rettv, map)
{
--todo;
di = HI2DI(hi);
- if (tv_check_lock(di->di_tv.v_lock, msg))
+ if (tv_check_lock(di->di_tv.v_lock, ermsg))
break;
vimvars[VV_KEY].vv_str = vim_strsave(di->di_key);
if (filter_map_one(&di->di_tv, expr, map, &rem) == FAIL
@@ -9248,7 +9248,7 @@ filter_map(argvars, rettv, map)
{
for (li = l->lv_first; li != NULL; li = nli)
{
- if (tv_check_lock(li->li_tv.v_lock, msg))
+ if (tv_check_lock(li->li_tv.v_lock, ermsg))
break;
nli = li->li_next;
if (filter_map_one(&li->li_tv, expr, map, &rem) == FAIL
@@ -19789,7 +19789,7 @@ call_user_func(fp, argcount, argvars, rettv, firstline, lastline, selfdict)
if (p_verbose >= 14)
{
char_u buf[MSG_BUF_LEN];
- char_u numbuf[NUMBUFLEN];
+ char_u numbuf2[NUMBUFLEN];
char_u *tofree;
msg_puts((char_u *)"(");
@@ -19801,8 +19801,8 @@ call_user_func(fp, argcount, argvars, rettv, firstline, lastline, selfdict)
msg_outnum((long)argvars[i].vval.v_number);
else
{
- trunc_string(tv2string(&argvars[i], &tofree, numbuf, 0),
- buf, MSG_BUF_CLEN);
+ trunc_string(tv2string(&argvars[i], &tofree,
+ numbuf2, 0), buf, MSG_BUF_CLEN);
msg_puts(buf);
vim_free(tofree);
}
@@ -19880,13 +19880,13 @@ call_user_func(fp, argcount, argvars, rettv, firstline, lastline, selfdict)
else
{
char_u buf[MSG_BUF_LEN];
- char_u numbuf[NUMBUFLEN];
+ char_u numbuf2[NUMBUFLEN];
char_u *tofree;
/* The value may be very long. Skip the middle part, so that we
* have some idea how it starts and ends. smsg() would always
* truncate it at the end. */
- trunc_string(tv2string(fc.rettv, &tofree, numbuf, 0),
+ trunc_string(tv2string(fc.rettv, &tofree, numbuf2, 0),
buf, MSG_BUF_CLEN);
smsg((char_u *)_("%s returning %s"), sourcing_name, buf);
vim_free(tofree);
diff --git a/src/ex_cmds.c b/src/ex_cmds.c
index b5920c8d04..70440735cc 100644
--- a/src/ex_cmds.c
+++ b/src/ex_cmds.c
@@ -185,6 +185,7 @@ ex_align(eap)
new_indent = indent;
else
{
+ has_tab = FALSE; /* avoid uninit warnings */
len = linelen(eap->cmdidx == CMD_right ? &has_tab
: NULL) - get_indent();
@@ -1772,10 +1773,9 @@ write_viminfo(file, forceit)
? (st_old.st_mode & 0020)
: (st_old.st_mode & 0002))))
{
- int tt;
+ int tt = msg_didany;
/* avoid a wait_return for this message, it's annoying */
- tt = msg_didany;
EMSG2(_("E137: Viminfo file is not writable: %s"), fname);
msg_didany = tt;
fclose(fp_in);
diff --git a/src/ex_cmds2.c b/src/ex_cmds2.c
index 4d01039ad0..50258725c3 100644
--- a/src/ex_cmds2.c
+++ b/src/ex_cmds2.c
@@ -3648,13 +3648,13 @@ do_finish(eap, reanimate)
* Return FALSE when not sourcing a file.
*/
int
-source_finished(getline, cookie)
- char_u *(*getline) __ARGS((int, void *, int));
+source_finished(fgetline, cookie)
+ char_u *(*fgetline) __ARGS((int, void *, int));
void *cookie;
{
- return (getline_equal(getline, cookie, getsourceline)
+ return (getline_equal(fgetline, cookie, getsourceline)
&& ((struct source_cookie *)getline_cookie(
- getline, cookie))->finished);
+ fgetline, cookie))->finished);
}
#endif
diff --git a/src/gui_beval.c b/src/gui_beval.c
index 655d5aedcc..804fa5a4e9 100644
--- a/src/gui_beval.c
+++ b/src/gui_beval.c
@@ -926,7 +926,7 @@ requestBalloon(beval)
# define IS_NONPRINTABLE(c) (((c) < 0x20 && (c) != TAB && (c) != NL) \
|| (c) == DEL)
static void
-set_printable_label_text(GtkLabel *label, char_u *msg)
+set_printable_label_text(GtkLabel *label, char_u *text)
{
char_u *convbuf = NULL;
char_u *buf;
@@ -940,14 +940,14 @@ set_printable_label_text(GtkLabel *label, char_u *msg)
/* Convert to UTF-8 if it isn't already */
if (output_conv.vc_type != CONV_NONE)
{
- convbuf = string_convert(&output_conv, msg, NULL);
+ convbuf = string_convert(&output_conv, text, NULL);
if (convbuf != NULL)
- msg = convbuf;
+ text = convbuf;
}
/* First let's see how much we need to allocate */
len = 0;
- for (p = msg; *p != NUL; p += charlen)
+ for (p = text; *p != NUL; p += charlen)
{
if ((*p & 0x80) == 0) /* be quick for ASCII */
{
@@ -992,7 +992,7 @@ set_printable_label_text(GtkLabel *label, char_u *msg)
(unsigned long)pixel, &color);
pdest = buf;
- p = msg;
+ p = text;
while (*p != NUL)
{
/* Be quick for ASCII */
diff --git a/src/gui_gtk.c b/src/gui_gtk.c
index 397b45180d..8751615bf2 100644
--- a/src/gui_gtk.c
+++ b/src/gui_gtk.c
@@ -957,15 +957,15 @@ toolbar_remove_item_by_text(GtkToolbar *tb, const char *text)
get_menu_position(vimmenu_T *menu)
{
vimmenu_T *node;
- int index = 0;
+ int idx = 0;
for (node = menu->parent->children; node != menu; node = node->next)
{
g_return_val_if_fail(node != NULL, -1);
- ++index;
+ ++idx;
}
- return index;
+ return idx;
}
#endif /* FEAT_TOOLBAR && HAVE_GTK2 */
@@ -2127,7 +2127,7 @@ dialog_add_buttons(GtkDialog *dialog, char_u *button_string)
char **ync; /* "yes no cancel" */
char **buttons;
int n_buttons = 0;
- int index;
+ int idx;
button_string = vim_strsave(button_string); /* must be writable */
if (button_string == NULL)
@@ -2161,12 +2161,12 @@ dialog_add_buttons(GtkDialog *dialog, char_u *button_string)
* Well, apparently somebody changed his mind: with GTK 2.2.4 it works the
* other way around...
*/
- for (index = 1; index <= n_buttons; ++index)
+ for (idx = 1; idx <= n_buttons; ++idx)
{
char *label;
char_u *label8;
- label = buttons[index - 1];
+ label = buttons[idx - 1];
/*
* Perform some guesswork to find appropriate stock items for the
* buttons. We have to compare with a sample of the translated
@@ -2188,7 +2188,7 @@ dialog_add_buttons(GtkDialog *dialog, char_u *button_string)
else if (button_equal(label, "Cancel")) label = GTK_STOCK_CANCEL;
}
label8 = CONVERT_TO_UTF8((char_u *)label);
- gtk_dialog_add_button(dialog, (const gchar *)label8, index);
+ gtk_dialog_add_button(dialog, (const gchar *)label8, idx);
CONVERT_TO_UTF8_FREE(label8);
}
diff --git a/src/gui_gtk_x11.c b/src/gui_gtk_x11.c
index 57797870c9..04ee0a0f4f 100644
--- a/src/gui_gtk_x11.c
+++ b/src/gui_gtk_x11.c
@@ -3233,12 +3233,12 @@ on_tabline_menu(GtkWidget *widget, GdkEvent *event)
on_select_tab(
GtkNotebook *notebook,
GtkNotebookPage *page,
- gint index,
+ gint idx,
gpointer data)
{
if (!ignore_tabline_evt)
{
- if (send_tabline_event(index + 1) && gtk_main_level() > 0)
+ if (send_tabline_event(idx + 1) && gtk_main_level() > 0)
gtk_main_quit();
}
}
@@ -5303,13 +5303,13 @@ gui_mch_get_fontname(GuiFont font, char_u *name)
# ifdef HAVE_GTK2
if (font != NOFONT)
{
- char *name = pango_font_description_to_string(font);
+ char *pangoname = pango_font_description_to_string(font);
- if (name != NULL)
+ if (pangoname != NULL)
{
- char_u *s = vim_strsave((char_u *)name);
+ char_u *s = vim_strsave((char_u *)pangoname);
- g_free(name);
+ g_free(pangoname);
return s;
}
}
@@ -6241,24 +6241,20 @@ gui_mch_invert_rectangle(int r, int c, int nr, int nc)
{
GdkGCValues values;
GdkGC *invert_gc;
- GdkColor foreground;
- GdkColor background;
if (gui.drawarea->window == NULL)
return;
- foreground.pixel = gui.norm_pixel ^ gui.back_pixel;
- background.pixel = gui.norm_pixel ^ gui.back_pixel;
-
- values.foreground = foreground;
- values.background = background;
+ values.foreground.pixel = gui.norm_pixel ^ gui.back_pixel;
+ values.background.pixel = gui.norm_pixel ^ gui.back_pixel;
values.function = GDK_XOR;
invert_gc = gdk_gc_new_with_values(gui.drawarea->window,
&values,
GDK_GC_FOREGROUND |
GDK_GC_BACKGROUND |
GDK_GC_FUNCTION);
- gdk_gc_set_exposures(invert_gc, gui.visibility != GDK_VISIBILITY_UNOBSCURED);
+ gdk_gc_set_exposures(invert_gc, gui.visibility !=
+ GDK_VISIBILITY_UNOBSCURED);
gdk_draw_rectangle(gui.drawarea->window, invert_gc,
TRUE,
FILL_X(c), FILL_Y(r),
diff --git a/src/hardcopy.c b/src/hardcopy.c
index b00322d473..cb9979234d 100644
--- a/src/hardcopy.c
+++ b/src/hardcopy.c
@@ -1794,29 +1794,27 @@ static struct prt_resfile_buffer_S prt_resfile;
static int
prt_resfile_next_line()
{
- int index;
+ int idx;
/* Move to start of next line and then find end of line */
- index = prt_resfile.line_end + 1;
- while (index < prt_resfile.len)
+ idx = prt_resfile.line_end + 1;
+ while (idx < prt_resfile.len)
{
- if (prt_resfile.buffer[index] != PSLF && prt_resfile.buffer[index]
- != PSCR)
+ if (prt_resfile.buffer[idx] != PSLF && prt_resfile.buffer[idx] != PSCR)
break;
- index++;
+ idx++;
}
- prt_resfile.line_start = index;
+ prt_resfile.line_start = idx;
- while (index < prt_resfile.len)
+ while (idx < prt_resfile.len)
{
- if (prt_resfile.buffer[index] == PSLF || prt_resfile.buffer[index]
- == PSCR)
+ if (prt_resfile.buffer[idx] == PSLF || prt_resfile.buffer[idx] == PSCR)
break;
- index++;
+ idx++;
}
- prt_resfile.line_end = index;
+ prt_resfile.line_end = idx;
- return (index < prt_resfile.len);
+ return (idx < prt_resfile.len);
}
static int
@@ -1837,14 +1835,14 @@ prt_resfile_strncmp(offset, string, len)
prt_resfile_skip_nonws(offset)
int offset;
{
- int index;
+ int idx;
- index = prt_resfile.line_start + offset;
- while (index < prt_resfile.line_end)
+ idx = prt_resfile.line_start + offset;
+ while (idx < prt_resfile.line_end)
{
- if (isspace(prt_resfile.buffer[index]))
- return index - prt_resfile.line_start;
- index++;
+ if (isspace(prt_resfile.buffer[idx]))
+ return idx - prt_resfile.line_start;
+ idx++;
}
return -1;
}
@@ -1853,14 +1851,14 @@ prt_resfile_skip_nonws(offset)
prt_resfile_skip_ws(offset)
int offset;
{
- int index;
+ int idx;
- index = prt_resfile.line_start + offset;
- while (index < prt_resfile.line_end)
+ idx = prt_resfile.line_start + offset;
+ while (idx < prt_resfile.line_end)
{
- if (!isspace(prt_resfile.buffer[index]))
- return index - prt_resfile.line_start;
- index++;
+ if (!isspace(prt_resfile.buffer[idx]))
+ return idx - prt_resfile.line_start;
+ idx++;
}
return -1;
}
@@ -2478,7 +2476,7 @@ mch_print_init(psettings, jobname, forceit)
char_u *p_encoding;
struct prt_ps_encoding_S *p_mbenc;
struct prt_ps_encoding_S *p_mbenc_first;
- struct prt_ps_charset_S *p_mbchar;
+ struct prt_ps_charset_S *p_mbchar = NULL;
#endif
#if 0
@@ -2516,7 +2514,6 @@ mch_print_init(psettings, jobname, forceit)
if (!(props & ENC_8BIT) && ((*p_pmcs != NUL) || !(props & ENC_UNICODE)))
{
p_mbenc_first = NULL;
- p_mbchar = NULL;
for (cmap = 0; cmap < NUM_ELEMENTS(prt_ps_mbfonts); cmap++)
if (prt_match_encoding((char *)p_encoding, &prt_ps_mbfonts[cmap],
&p_mbenc))
diff --git a/src/if_cscope.c b/src/if_cscope.c
index 1eb3616e75..df3213c039 100644
--- a/src/if_cscope.c
+++ b/src/if_cscope.c
@@ -989,8 +989,7 @@ cs_find_common(opt, pat, forceit, verbose, use_ll)
{
int i;
char *cmd;
- char **matches, **contexts;
- int nummatches[CSCOPE_MAX_CONNECTIONS], totmatches, matched;
+ int nummatches[CSCOPE_MAX_CONNECTIONS], totmatches;
#ifdef FEAT_QUICKFIX
char cmdletter;
char *qfpos;
@@ -1141,6 +1140,9 @@ cs_find_common(opt, pat, forceit, verbose, use_ll)
else
#endif /* FEAT_QUICKFIX */
{
+ char **matches = NULL, **contexts = NULL;
+ int matched = 0;
+
/* read output */
cs_fill_results((char *)pat, totmatches, nummatches, &matches,
&contexts, &matched);
diff --git a/src/main.c b/src/main.c
index 8c32106a39..5051adbf97 100644
--- a/src/main.c
+++ b/src/main.c
@@ -2285,7 +2285,7 @@ create_windows(parmp)
mparm_T *parmp;
{
#ifdef FEAT_WINDOWS
- int rewind;
+ int dorewind;
int done = 0;
/*
@@ -2342,10 +2342,10 @@ create_windows(parmp)
++autocmd_no_leave;
#endif
#ifdef FEAT_WINDOWS
- rewind = TRUE;
+ dorewind = TRUE;
while (done++ < 1000)
{
- if (rewind)
+ if (dorewind)
{
if (parmp->window_layout == WIN_TABS)
goto_tabpage(1);
@@ -2364,7 +2364,7 @@ create_windows(parmp)
break;
curwin = curwin->w_next;
}
- rewind = FALSE;
+ dorewind = FALSE;
#endif
curbuf = curwin->w_buffer;
if (curbuf->b_ml.ml_mfp == NULL)
@@ -2385,7 +2385,7 @@ create_windows(parmp)
check_swap_exists_action();
#endif
#ifdef FEAT_AUTOCMD
- rewind = TRUE; /* start again */
+ dorewind = TRUE; /* start again */
#endif
}
#ifdef FEAT_WINDOWS
diff --git a/src/mbyte.c b/src/mbyte.c
index 92f00e093c..085b0eac87 100644
--- a/src/mbyte.c
+++ b/src/mbyte.c
@@ -3861,13 +3861,13 @@ im_get_feedback_attr(int col)
if (preedit_string != NULL && attr_list != NULL)
{
- int index;
+ int idx;
/* Get the byte index as used by PangoAttrIterator */
- for (index = 0; col > 0 && preedit_string[index] != '\0'; --col)
- index += utfc_ptr2len((char_u *)preedit_string + index);
+ for (idx = 0; col > 0 && preedit_string[idx] != '\0'; --col)
+ idx += utfc_ptr2len((char_u *)preedit_string + idx);
- if (preedit_string[index] != '\0')
+ if (preedit_string[idx] != '\0')
{
PangoAttrIterator *iter;
int start, end;
@@ -3880,7 +3880,7 @@ im_get_feedback_attr(int col)
{
pango_attr_iterator_range(iter, &start, &end);
- if (index >= start && index < end)
+ if (idx >= start && idx < end)
char_attr |= translate_pango_attributes(iter);
}
while (pango_attr_iterator_next(iter));
diff --git a/src/memline.c b/src/memline.c
index e86a792a5a..6ea2dc5dad 100644
--- a/src/memline.c
+++ b/src/memline.c
@@ -215,7 +215,7 @@ static linenr_T lowest_marked = 0;
#define ML_FLUSH 0x02 /* flush locked block */
#define ML_SIMPLE(x) (x & 0x10) /* DEL, INS or FIND */
-static void ml_upd_block0 __ARGS((buf_T *buf, int setfname));
+static void ml_upd_block0 __ARGS((buf_T *buf, int set_fname));
static void set_b0_fname __ARGS((ZERO_BL *, buf_T *buf));
static void set_b0_dir_flag __ARGS((ZERO_BL *b0p, buf_T *buf));
#ifdef FEAT_MBYTE
@@ -679,9 +679,9 @@ ml_timestamp(buf)
* Update the timestamp or the B0_SAME_DIR flag of the .swp file.
*/
static void
-ml_upd_block0(buf, setfname)
+ml_upd_block0(buf, set_fname)
buf_T *buf;
- int setfname;
+ int set_fname;
{
memfile_T *mfp;
bhdr_T *hp;
@@ -695,7 +695,7 @@ ml_upd_block0(buf, setfname)
EMSG(_("E304: ml_upd_block0(): Didn't get block 0??"));
else
{
- if (setfname)
+ if (set_fname)
set_b0_fname(b0p, buf);
else
set_b0_dir_flag(b0p, buf);
diff --git a/src/netbeans.c b/src/netbeans.c
index 98c9a35152..409580ad4c 100644
--- a/src/netbeans.c
+++ b/src/netbeans.c
@@ -103,7 +103,7 @@ static gint inputHandler; /* Cookie for input */
static int inputHandler = -1; /* simply ret.value of WSAAsyncSelect() */
extern HWND s_hwnd; /* Gvim's Window handle */
#endif
-static int cmdno; /* current command number for reply */
+static int r_cmdno; /* current command number for reply */
static int haveConnection = FALSE; /* socket is connected and
initialization is done */
#ifdef FEAT_GUI_MOTIF
@@ -832,11 +832,11 @@ nb_parse_cmd(char_u *cmd)
return;
}
- cmdno = strtol(q, &q, 10);
+ r_cmdno = strtol(q, &q, 10);
q = (char *)skipwhite((char_u *)q);
- if (nb_do_cmd(bufno, (char_u *)verb, isfunc, cmdno, (char_u *)q) == FAIL)
+ if (nb_do_cmd(bufno, (char_u *)verb, isfunc, r_cmdno, (char_u *)q) == FAIL)
{
diff --git a/src/ex_docmd.c b/src/ex_docmd.c
index e78f762440..0019055074 100644
--- a/src/ex_docmd.c
+++ b/src/ex_docmd.c
@@ -58,9 +58,9 @@ static char_u *get_user_command_name __ARGS((int idx));
#endif
#ifdef FEAT_EVAL
-static char_u *do_one_cmd __ARGS((char_u **, int, struct condstack *, char_u *(*getline)(int, void *, int), void *cookie));
+static char_u *do_one_cmd __ARGS((char_u **, int, struct condstack *, char_u *(*fgetline)(int, void *, int), void *cookie));
#else
-static char_u *do_one_cmd __ARGS((char_u **, int, char_u *(*getline)(int, void *, int), void *cookie));
+static char_u *do_one_cmd __ARGS((char_u **, int, char_u *(*fgetline)(int, void *, int), void *cookie));
static int if_level = 0; /* depth in :if */
#endif
static char_u *find_command __ARGS((exarg_T *eap, int *full));
@@ -831,10 +831,13 @@ do_cmdline(cmdline, getline, cookie, flags)
/*
* If requested, store and reset the global values controlling the
- * exception handling (used when debugging).
+ * exception handling (used when debugging). Otherwise clear it to avoid
+ * a bogus compiler warning when the optimizer uses inline functions...
*/
if (flags & DOCMD_EXCRESET)
save_dbg_stuff(&debug_saved);
+ else
+ memset(&debug_saved, 0, 1);
initial_trylevel = trylevel;
@@ -1574,24 +1577,24 @@ free_cmdlines(gap)
#endif
/*
* If "getline" is get_loop_line(), return TRUE if the getline it uses equals
* "func". * Otherwise return TRUE when "getline" equals "func".
*/
/*ARGSUSED*/
int
-getline_equal(getline, cookie, func)
- char_u *(*getline) __ARGS((int, void *, int));
- void *cookie; /* argument for getline() */
+getline_equal(fgetline, cookie, func)
+ char_u *(*fgetline) __ARGS((int, void *, int));
+ void *cookie; /* argument for fgetline() */
char_u *(*func) __ARGS((int, void *, int));
{
#ifdef FEAT_EVAL
char_u *(*gp) __ARGS((int, void *, int));
struct loop_cookie *cp;
/* When "getline" is "get_loop_line()" use the "cookie" to find the
* function that's orignally used to obtain the lines. This may be nested
* several levels. */
- gp = getline;
+ gp = fgetline;
cp = (struct loop_cookie *)cookie;
while (gp == get_loop_line)
{
@@ -1600,29 +1603,29 @@ getline_equal(getline, cookie, func)
}
return gp == func;
#else
- return getline == func;
+ return fgetline == func;
#endif
}
#if defined(FEAT_EVAL) || defined(FEAT_MBYTE) || defined(PROTO)
/*
* If "getline" is get_loop_line(), return the cookie used by the original
* getline function. Otherwise return "cookie".
*/
/*ARGSUSED*/
void *
-getline_cookie(getline, cookie)
- char_u *(*getline) __ARGS((int, void *, int));
- void *cookie; /* argument for getline() */
+getline_cookie(fgetline, cookie)
+ char_u *(*fgetline) __ARGS((int, void *, int));
+ void *cookie; /* argument for fgetline() */
{
# ifdef FEAT_EVAL
char_u *(*gp) __ARGS((int, void *, int));
struct loop_cookie *cp;
/* When "getline" is "get_loop_line()" use the "cookie" to find the
* cookie that's orignally used to obtain the lines. This may be nested
* several levels. */
- gp = getline;
+ gp = fgetline;
cp = (struct loop_cookie *)cookie;
while (gp == get_loop_line)
{
@@ -1648,7 +1651,7 @@ getline_cookie(getline, cookie)
* 5. parse arguments
* 6. switch on command name
*
* Note: "getline" can be NULL.
*
* This function may be called recursively!
*/
@@ -1663,14 +1666,14 @@ do_one_cmd(cmdlinep, sourcing,
#ifdef FEAT_EVAL
cstack,
#endif
- getline, cookie)
+ fgetline, cookie)
char_u **cmdlinep;
int sourcing;
#ifdef FEAT_EVAL
struct condstack *cstack;
#endif
- char_u *(*getline) __ARGS((int, void *, int));
- void *cookie; /* argument for getline() */
+ char_u *(*fgetline) __ARGS((int, void *, int));
+ void *cookie; /* argument for fgetline() */
{
char_u *p;
linenr_T lnum;
@@ -1698,7 +1701,7 @@ do_one_cmd(cmdlinep, sourcing,
if (quitmore
#ifdef FEAT_EVAL
/* avoid that a function call in 'statusline' does this */
- && !getline_equal(getline, cookie, get_func_line)
+ && !getline_equal(fgetline, cookie, get_func_line)
#endif
)
--quitmore;
@@ -1728,8 +1731,8 @@ do_one_cmd(cmdlinep, sourcing,
/* in ex mode, an empty line works like :+ */
if (*ea.cmd == NUL && exmode_active
- && (getline_equal(getline, cookie, getexmodeline)
- || getline_equal(getline, cookie, getexline))
+ && (getline_equal(fgetline, cookie, getexmodeline)
+ || getline_equal(fgetline, cookie, getexline))
&& curwin->w_cursor.lnum < curbuf->b_ml.ml_line_count)
{
ea.cmd = (char_u *)"+";
@@ -1918,9 +1921,9 @@ do_one_cmd(cmdlinep, sourcing,
/* Count this line for profiling if ea.skip is FALSE. */
if (do_profiling == PROF_YES && !ea.skip)
{
- if (getline_equal(getline, cookie, get_func_line))
- func_line_exec(getline_cookie(getline, cookie));
- else if (getline_equal(getline, cookie, getsourceline))
+ if (getline_equal(fgetline, cookie, get_func_line))
+ func_line_exec(getline_cookie(fgetline, cookie));
+ else if (getline_equal(fgetline, cookie, getsourceline))
script_line_exec();
}
#endif
@@ -2589,7 +2592,7 @@ do_one_cmd(cmdlinep, sourcing,
* The "ea" structure holds the arguments that can be used.
*/
ea.cmdlinep = cmdlinep;
- ea.getline = getline;
+ ea.getline = fgetline;
ea.cookie = cookie;
#ifdef FEAT_EVAL
ea.cstack = cstack;
@@ -2627,9 +2630,9 @@ do_one_cmd(cmdlinep, sourcing,
do_throw(cstack);
else if (check_cstack)
{
- if (source_finished(getline, cookie))
+ if (source_finished(fgetline, cookie))
do_finish(&ea, TRUE);
- else if (getline_equal(getline, cookie, get_func_line)
+ else if (getline_equal(fgetline, cookie, get_func_line)
&& current_func_returned())
do_return(&ea, TRUE, FALSE, NULL);
}
@@ -1574,24 +1577,24 @@ free_cmdlines(gap)
#endif
/*
- * If "getline" is get_loop_line(), return TRUE if the getline it uses equals
- * "func". * Otherwise return TRUE when "getline" equals "func".
+ * If "fgetline" is get_loop_line(), return TRUE if the getline it uses equals
+ * "func". * Otherwise return TRUE when "fgetline" equals "func".
*/
/*ARGSUSED*/
@@ -1574,24 +1577,24 @@ free_cmdlines(gap)
char_u *(*gp) __ARGS((int, void *, int));
struct loop_cookie *cp;
- /* When "getline" is "get_loop_line()" use the "cookie" to find the
+ /* When "fgetline" is "get_loop_line()" use the "cookie" to find the
* function that's orignally used to obtain the lines. This may be nested
* several levels. */
@@ -1600,29 +1603,29 @@ getline_equal(getline, cookie, func)
#if defined(FEAT_EVAL) || defined(FEAT_MBYTE) || defined(PROTO)
/*
- * If "getline" is get_loop_line(), return the cookie used by the original
+ * If "fgetline" is get_loop_line(), return the cookie used by the original
* getline function. Otherwise return "cookie".
*/
@@ -1600,29 +1603,29 @@ getline_equal(getline, cookie, func)
char_u *(*gp) __ARGS((int, void *, int));
struct loop_cookie *cp;
- /* When "getline" is "get_loop_line()" use the "cookie" to find the
+ /* When "fgetline" is "get_loop_line()" use the "cookie" to find the
* cookie that's orignally used to obtain the lines. This may be nested
* several levels. */
@@ -1648,7 +1651,7 @@ getline_cookie(getline, cookie)
* 6. switch on command name
*
- * Note: "getline" can be NULL.
+ * Note: "fgetline" can be NULL.
*
* This function may be called recursively!